from resources.init import Init
from resources.init import InitEnv
from resources.operations import Operations


def main():
    options = Init.parse_args()
    env = InitEnv(base_url=options.base_url, token=options.token, username=options.username, password=options.password)
    base_url, session = Init.get_creds(env)

    available_teams = []
    for team in Operations.get_available_teams(base_url, session):
        available_teams.append({'username': team['username'], 'displayname': team['display_name']})

    team_selection = ""
    for position, team in enumerate(available_teams):
        team_selection += f"{team['displayname']} [{position}], "
    team_id = int(input(f"Please Select the number value of the team you wish to reset:\n{team_selection}\n"))
    team = available_teams[team_id]['username']

    repos_to_delete = []
    for repo in Operations.get_repos(base_url, session, team):
        repos_to_delete.append(repo['slug'])

    for repo in repos_to_delete:
        Operations.delete_repo(base_url, session, team, repo)
        print(f"Delete repo: {repo} from within the workspace {team}")

    # Due to projects being present under both "teams" and "workspaces" we duplicate the work to both to locate and remove the projects

    team_projects = []
    for project in Operations.get_team_projects(base_url, session, team):
        team_projects.append(project['key'])

    for project in team_projects:
        Operations.delete_team_projects(base_url, session, team, project)
        print(f"Deleting the project '{project}' from the team '{team}'")

    workspace_projects = []
    for project in Operations.get_workspace_projects(base_url, session, team):
        workspace_projects.append(project['key'])

    for project in workspace_projects:
        Operations.delete_workspace_project(base_url, session, team, project)
        print(f"Deleting the project '{project}' from the workspace '{team}'")


if __name__ == '__main__':
    main()
