from resources.connections import Connections


class Operations():
    def get_available_teams(base_url, session, paged_start=None):
        while True:
            params = {'role': 'member', 'page': paged_start}
            url = f'{base_url}/2.0/teams'
            r = Connections.get_api(session, url, params)
            r_data = r.json()
            for team in r_data['values']:
                yield team
            if r_data.get('next') is None:
                return
            paged_start = r_data['page'] + 1

    def get_repos(base_url, session, team, paged_start=None):
        while True:
            params = {'page': paged_start}
            url = f'{base_url}/2.0/repositories/{team}'
            r = Connections.get_api(session, url, params)
            r_data = r.json()
            for repo in r_data['values']:
                yield repo
            if r_data.get('next') is None:
                return
            paged_start = r_data['page'] + 1

    def delete_repo(base_url, session, team, repo):
        url = f'{base_url}/2.0/repositories/{team}/{repo}'
        Connections.delete_api(session, url)

    def get_team_projects(base_url, session, team, paged_start=None):
        while True:
            params = {'page': paged_start}
            url = f'{base_url}/2.0/teams/{team}/projects'
            r = Connections.get_api(session, url, params)
            r_data = r.json()
            try:
                for team in r_data['values']:
                    yield team
                if r_data.get('next') is None:
                    return
                paged_start = r_data['page'] + 1
            except KeyError:
                # No content found, returning
                return

    def delete_team_projects(base_url, session, team, project):
        url = f'{base_url}/2.0/teams/{team}/projects/{project}'
        Connections.delete_api(session, url)

    def delete_workspace_project(base_url, session, team, project):
        url = f'{base_url}/2.0/workspaces/{team}/projects/{project}'
        Connections.delete_api(session, url)

    def get_workspace_projects(base_url, session, team, paged_start=None):
        while True:
            params = {'page': paged_start}
            url = f'{base_url}/2.0/workspaces/{team}/projects'
            r = Connections.get_api(session, url, params)
            r_data = r.json()
            try:
                for team in r_data['values']:
                    yield team
                if r_data.get('next') is None:
                    return
                paged_start = r_data['page'] + 1
            except KeyError:
                return
